jj.saola


start-systemclj

(start-system components config)

Start all components in dependency order. components is a plain sequence (list, vector, …) of component records — no pre-registration needed. Returns a system map that can be passed directly to stop-system.

Start all components in dependency order.
`components` is a plain sequence (list, vector, …) of component records —
no pre-registration needed.
Returns a system map that can be passed directly to `stop-system`.
sourceraw docstring

stop-systemclj

(stop-system system)

Stop all services in the system, in reverse dependency order. Only the system map returned by start-system is required — no registry.

Stop all services in the system, in reverse dependency order.
Only the system map returned by `start-system` is required — no registry.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries